==> nextcloud-32.0.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/app_api/l10n/zh_CN.js <==
OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "未找到守护进程配置",
    "Error starting install of ExApp" : "开始安装外部应用时发生错误",
    "Failed to enable ExApp" : "无法启用外部程序",
    "Failed to disable ExApp" : "无法禁用外部程序",
    "Could not update ExApp" : "无法更新外部程序",
    "AppAPI authentication failed" : "AppAPI 验证失败",
    "AppAPI ExApp notifier" : "AppAPI 外部程序通知",
    "AppAPI" : "AppAPI",
    "AI Integration Team" : "AI 集成团队",
    "ExApps Settings" : "外部应用设置",
    "Nextcloud AppAPI" : "Nextcloud AppAPI",
    "External Apps management" : "外部应用管理",
    "Admin options saved" : "已保存管理员选项",
    "Failed to save admin options" : "保存管理员选项失败",
    "Deploy Daemons" : "部署守护进程",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "部署守护进程（DaemonConfig）是外部应用的编排守护进程。",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "部署守护进程。部署守护进程（DaemonConfig）是外部应用的编排守护进程。",
    "ExApp init timeout (minutes)" : "外部应用初始化超时（分钟）",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "外部应用初始化过程超时后，AppAPI 将其标记为已失败",
    "ExApp init timeout" : "外部应用初始化超时",
    "ExApp container restart policy" : "外部应用容器重启策略",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "指定容器重启策略，例如“always”，以确保外部应用在守护进程服务重启后运行",
    "This settings changes are reflected only for newly created containers" : "此设置更改仅适用于新创建的容器",
    "Cancel" : "取消",
    "Delete" : "删除",
    "Default" : "默认",
    "Edit" : "编辑",
    "Deploy Daemon" : "部署守护进程",
    "Name" : "名称",
    "Host" : "主机",
    "Nextcloud URL" : "Nextcloud URL ",
    "GPUs support" : "GPU 支持",
    "Compute device" : "计算设备",
    "Registered Deploy daemons list" : "已注册的部署守护进程列表",
    "No Deploy daemons configured" : "没有部署守护进程配置",
    "Register a custom one or setup from available templates" : "注册自定义模板或从可用模板进行安装",
    "Register Daemon" : "注册守护进程",
    "Enabled" : "已启用",
    "Remove" : "移除",
    "From" : "来自",
    "To" : "给",
    "Add" : "添加",
    "Register Deploy Daemon" : "注册部署守护进程",
    "Display name" : "显示名称",
    "Deployment method" : "部署方式",
    "Disabled" : "已禁用",
    "Confirm" : "确认",
    "Save" : "保存",
    "Register" : "注册",
    "External Apps" : "外部应用",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "AppAPI 项目是一项令人兴奋的计划，旨在彻底改变为 Nextcloud 开发应用程序的方式。",
    "{license}-licensed" : "{license}-许可协议",
    "Update to {version}" : "更新至 {version}",
    "Delete data on remove" : "移除时删除数据",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "该应用没有指定支持的 Nextcloud 最低版本。可能会在将来出现问题。",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "该应用没有指定支持的 Nextcloud 最高版本。可能会在将来出现问题。",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "无法安装应用，因为无法满足下列依赖：",
    "View in store" : "在商店中查看",
    "Visit website" : "访问网站",
    "Report a bug" : "报告 Bug",
    "User documentation" : "用户文档",
    "Admin documentation" : "管理员文档",
    "Developer documentation" : "开发者文档",
    "This app is supported via your current Nextcloud subscription." : "根据你当前的 Nextcloud 订阅，此应用受到支持。",
    "Supported" : "受支持",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "特色应用由社区并在社区内开发。 它们提供了中心功能，并准备投入生产使用。",
    "Featured" : "精选",
    "Update to {update}" : "更新至 {update}",
    "Default Deploy daemon is not accessible" : "默认部署守护程序不可访问",
    "Icon" : "图标",
    "Version" : "版本",
    "Daemon" : "守护进程",
    "Level" : "级别",
    "Actions" : "操作",
    "Results from other categories" : "来自其他类别的结果",
    "_Update_::_Update all_" : ["全部更新"],
    "Type" : "类型",
    "Display Name" : "显示名称",
    "Network" : "网络",
    "by {author}\n{license}" : "按照 {author}\n{license}",
    "Your apps" : "您的应用",
    "Documentation" : "文档",
    "Details" : "详情",
    "Changelog" : "更新日志",
    "Active apps" : "已启用的应用",
    "Disabled apps" : "已禁用的应用",
    "Updates" : "更新",
    "Featured apps" : "精选应用",
    "Supported apps" : "支持的应用",
    "manual-install apps cannot be updated" : "手动安装的应用程序无法更新",
    "Deploy and Enable" : "部署并启用",
    "Enable" : "开启",
    "Disable" : "禁用",
    "Allow untested app" : "允许未经测试的应用",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "此应用被标记为与您的 Nextcloud 版本不兼容。如果您要继续，您仍可安装此应用。请注意此应用可能不会正常工作。",
    "An error occurred during the request. Unable to proceed." : "请求期间发生错误。无法继续。",
    "The app has been enabled but needs to be updated." : "该应用程序已启用但需要更新。",
    "Error: This app cannot be enabled because it makes the server unstable" : "错误:这个应用程序不能被启用，因为它使服务器不稳定 "
},
"nplurals=1; plural=0;");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/app_api/l10n/zh_CN.js <==
OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "未找到守护进程配置",
    "Error starting install of ExApp" : "开始安装外部应用时发生错误",
    "Failed to enable ExApp" : "无法启用外部程序",
    "Failed to disable ExApp" : "无法禁用外部程序",
    "Could not update ExApp" : "无法更新外部程序",
    "AppAPI authentication failed" : "AppAPI 验证失败",
    "AppAPI ExApp notifier" : "AppAPI 外部程序通知",
    "AppAPI" : "AppAPI",
    "AI Integration Team" : "AI 集成团队",
    "ExApps Settings" : "外部应用设置",
    "Nextcloud AppAPI" : "Nextcloud AppAPI",
    "External Apps management" : "外部应用管理",
    "Admin options saved" : "已保存管理员选项",
    "Failed to save admin options" : "保存管理员选项失败",
    "ExApp init timeout (minutes)" : "外部应用初始化超时（分钟）",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "外部应用初始化过程超时后，AppAPI 将其标记为已失败",
    "ExApp init timeout" : "外部应用初始化超时",
    "ExApp container restart policy" : "外部应用容器重启策略",
    "Cancel" : "取消",
    "Delete" : "删除",
    "Default" : "默认",
    "Edit" : "编辑",
    "Unlimited" : "无限制",
    "Name" : "名称",
    "Protocol" : "协议",
    "Host" : "主机",
    "Deploy options" : "部署选项",
    "Nextcloud URL" : "Nextcloud URL ",
    "Memory limit" : "内存限制",
    "Registered Deploy daemons list" : "已注册的部署守护进程列表",
    "Heartbeat" : "心跳",
    "Enabled" : "已启用",
    "More information" : "更多信息",
    "Remove" : "移除",
    "From" : "来自",
    "To" : "给",
    "Add" : "添加",
    "Display name" : "显示名称",
    "Deployment method" : "部署方式",
    "Compute device" : "计算设备",
    "Confirm" : "确认",
    "Save" : "保存",
    "Register" : "注册",
    "External Apps" : "外部应用",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "AppAPI 项目是一项令人兴奋的计划，旨在彻底改变为 Nextcloud 开发应用程序的方式。",
    "Deploy Daemons" : "部署守护进程",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "部署守护进程（DaemonConfig）是外部应用的编排守护进程。",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "部署守护进程。部署守护进程（DaemonConfig）是外部应用的编排守护进程。",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "指定容器重启策略，例如“always”，以确保外部应用在守护进程服务重启后运行",
    "This settings changes are reflected only for newly created containers" : "此设置更改仅适用于新创建的容器",
    "{license}-licensed" : "{license}-许可协议",
    "Update to {version}" : "更新至 {version}",
    "Delete data on remove" : "移除时删除数据",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "该应用没有指定支持的 Nextcloud 最低版本。可能会在将来出现问题。",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "该应用没有指定支持的 Nextcloud 最高版本。可能会在将来出现问题。",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "无法安装应用，因为无法满足下列依赖：",
    "View in store" : "在商店中查看",
    "Visit website" : "访问网站",
    "Report a bug" : "报告 Bug",
    "User documentation" : "用户文档",
    "Admin documentation" : "管理员文档",
    "Developer documentation" : "开发者文档",
    "This app is supported via your current Nextcloud subscription." : "根据你当前的 Nextcloud 订阅，此应用受到支持。",
    "Supported" : "受支持",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "特色应用由社区并在社区内开发。 它们提供了中心功能，并准备投入生产使用。",
    "Featured" : "精选",
    "Update to {update}" : "更新至 {update}",
    "Default Deploy daemon is not accessible" : "默认部署守护程序不可访问",
    "Icon" : "图标",
    "Version" : "版本",
    "Daemon" : "守护进程",
    "Level" : "级别",
    "Actions" : "操作",
    "Results from other categories" : "来自其他类别的结果",
    "_Update_::_Update all_" : ["全部更新"],
    "Deploy Daemon" : "部署守护进程",
    "Type" : "类型",
    "Display Name" : "显示名称",
    "GPUs support" : "GPU 支持",
    "No Deploy daemons configured" : "没有部署守护进程配置",
    "Register a custom one or setup from available templates" : "注册自定义模板或从可用模板进行安装",
    "Register Daemon" : "注册守护进程",
    "Register Deploy Daemon" : "注册部署守护进程",
    "Network" : "网络",
    "by {author}\n{license}" : "按照 {author}\n{license}",
    "Your apps" : "您的应用",
    "Documentation" : "文档",
    "Details" : "详情",
    "Changelog" : "更新日志",
    "Active apps" : "已启用的应用",
    "Disabled apps" : "已禁用的应用",
    "Updates" : "更新",
    "Featured apps" : "精选应用",
    "Supported apps" : "支持的应用",
    "manual-install apps cannot be updated" : "手动安装的应用程序无法更新",
    "Healthchecking" : "健康度检查",
    "Deploy and Enable" : "部署并启用",
    "Enable" : "开启",
    "Disable" : "禁用",
    "Allow untested app" : "允许未经测试的应用",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "此应用被标记为与您的 Nextcloud 版本不兼容。如果您要继续，您仍可安装此应用。请注意此应用可能不会正常工作。",
    "An error occurred during the request. Unable to proceed." : "请求期间发生错误。无法继续。",
    "The app has been enabled but needs to be updated." : "该应用程序已启用但需要更新。",
    "Error: This app cannot be enabled because it makes the server unstable" : "错误:这个应用程序不能被启用，因为它使服务器不稳定 "
},
"nplurals=1; plural=0;");
